@@ -2,7 +2,7 @@ findFn <- function(string,
                    maxPages = 20,
                    sortby = NULL,
                    verbose = 1, ...) {
-  ##############################################################################
+  ####################################################################
   ##
   ## RSiteSearch(string, "fun")
   ##
@@ -17,7 +17,7 @@ findFn <- function(string,
   ##      so sum(summary) may be less than hits.
   ##
   ##
-  ##############################################################################
+  ####################################################################
   ## 0.  Set up
   ##
   quiet <- (verbose < 2)
@@ -36,7 +36,7 @@ findFn <- function(string,
       attr(ans, "matches") <- 0
       return(ans)
     }
-    html <- scan(link, what = "", quiet = quiet, sep = "\n")
+    html <- readLines(link)
     hitPattern <- "^.*<!-- HIT -->(.*)<!-- HIT -->.*$"
     hitRows <- html[grep(hitPattern, html, useBytes = TRUE)]
     hits <- as.numeric(sub(hitPattern, "\\1", hitRows, useBytes = TRUE))
@@ -48,8 +48,9 @@ findFn <- function(string,
     pac <- sub(pattern, "\\1", links, useBytes = TRUE)
     fun <- sub(pattern, "\\2", links, useBytes = TRUE)
     scoreLoc <- regexpr("score:", links, useBytes = TRUE)
-    scorePattern <- "^.*\\(score: ([0-9]+)\\)$"
-    score <- as.numeric(sub(scorePattern, "\\1", links, useBytes = TRUE))
+    scorePattern <- "^.*\\(score: ([0-9]+)\\).*$"
+    scoreCh <- sub(scorePattern, "\\1", links, useBytes = TRUE)
+    score <- as.numeric(scoreCh)
     Date <- sub("^.*<em>(.*)</em>.*$", "\\1", dates, useBytes = TRUE)
     lnk <- sub("<dt>.*<strong><a href=\\\"(.*)\\\">R:.*$", "\\1",
                links, useBytes = TRUE)
@@ -77,8 +78,11 @@ findFn <- function(string,
     attr(ans, "matches") <- hits
     ans
   }
-  if (substr(string, 1, 1) != "{")
+  if (substr(string, 1, 1) != "{") {
     string <- gsub(" ", "+", string)
+  } else {  ## scan(url(...)) fails with spaces
+    string <- gsub(" ", "%20", string)
+  }
   fmt <- paste("http://search.r-project.org/cgi-bin/namazu.cgi?",
                "query=%s&max=20&result=normal&sort=score&idxname=functions",
                sep = "")
